==> manga_reader-0.0.1.tar.gz: lib/ui/custom_bottom_bar.dart <==
import 'package:flutter/material.dart';
import 'package:manga_reader/const.dart';
import 'package:manga_reader/int_callback.dart';
import 'package:manga_reader/ui/images-scroll_view.dart';
import 'package:manga_reader/ui/sliders_widget.dart';

class CustomBottomBar extends StatelessWidget {
  bool showAppbar;
  VoidCallback previousButtonPressed;
  VoidCallback nextButtonPressed;
  IntCallback jumpToPage;
  int numberTotalPage;

  CustomBottomBar(this.showAppbar, {this.previousButtonPressed, this.nextButtonPressed, this.jumpToPage, this.numberTotalPage});

  @override
  Widget build(BuildContext context) {
    return AnimatedContainer(
      height: showAppbar ? bottomBarSize(context) : 0,
      duration: appBarAnimationDuration(),
      color: appBarColor(),
      child: _Content(showAppbar, previousButtonPressed, nextButtonPressed, jumpToPage, numberTotalPage),
    );
  }
}

class _Content extends StatelessWidget {
  bool showAppbar;
  int numberTotalPage;
  VoidCallback previousButtonPressed;
  VoidCallback nextButtonPressed;
  IntCallback jumpToPage;

  _Content(this.showAppbar, this.previousButtonPressed, this.nextButtonPressed, this.jumpToPage, this.numberTotalPage);

  @override
  Widget build(BuildContext context) {
    return showAppbar ? ValueListenableBuilder(
        valueListenable: ImagesScrollView.currentPageIndex,
        builder: (BuildContext context, int currentPageIndex, Widget child) {
          return Row(
            children: <Widget>[
              Expanded(
                child: IconButton(
                  icon: Icon(Icons.arrow_back, color: appBarContentColor()),
                  onPressed: () => previousButtonPressed(),
                ),
                flex: 10,
              ),
              Expanded(
                child: SliderWidget(
                  value: currentPageIndex/numberTotalPage,
                  min: 1,
                  max: numberTotalPage,
                  sliderHeight: bottomBarSize(context) * 0.6,
                  onChangeValue: (value) => jumpToPage(value),
                ),
                flex: 80,
              ),
              Expanded(
                child: IconButton(
                  icon: Icon(Icons.arrow_forward, color: appBarContentColor()),
                  onPressed: () => nextButtonPressed(),
                ),
                flex: 10,
              )
            ],
          );
        }): Container();
  }
}

==> manga_reader-0.0.2.tar.gz: lib/ui/custom_bottom_bar.dart <==
import 'package:flutter/material.dart';
import 'package:manga_reader/const.dart';
import 'package:manga_reader/int_callback.dart';
import 'package:manga_reader/ui/images-scroll_view.dart';
import 'package:manga_reader/ui/sliders_widget.dart';

class CustomBottomBar extends StatelessWidget {
  bool showAppbar;
  VoidCallback previousButtonPressed;
  VoidCallback nextButtonPressed;
  IntCallback jumpToPage;
  int numberTotalPage;

  CustomBottomBar(this.showAppbar, {this.previousButtonPressed, this.nextButtonPressed, this.jumpToPage, this.numberTotalPage});

  @override
  Widget build(BuildContext context) {
    return AnimatedContainer(
      height: showAppbar ? bottomBarSize(context) : 0,
      duration: appBarAnimationDuration(),
      color: appBarColor(),
      child: _Content(showAppbar, previousButtonPressed, nextButtonPressed, jumpToPage, numberTotalPage),
    );
  }
}

class _Content extends StatelessWidget {
  bool showAppbar;
  int numberTotalPage;
  VoidCallback previousButtonPressed;
  VoidCallback nextButtonPressed;
  IntCallback jumpToPage;

  _Content(this.showAppbar, this.previousButtonPressed, this.nextButtonPressed, this.jumpToPage, this.numberTotalPage);

  @override
  Widget build(BuildContext context) {
    return showAppbar && numberTotalPage > 1 ? ValueListenableBuilder(
        valueListenable: ImagesScrollView.currentPageIndex,
        builder: (BuildContext context, int currentPageIndex, Widget child) {
          return Row(
            children: <Widget>[
              Expanded(
                child: IconButton(
                  icon: Icon(Icons.arrow_back, color: appBarContentColor()),
                  onPressed: () => previousButtonPressed(),
                ),
                flex: 10,
              ),
              Expanded(
                child: SliderWidget(
                  value: currentPageIndex/numberTotalPage,
                  min: 1,
                  max: numberTotalPage,
                  sliderHeight: bottomBarSize(context) * 0.6,
                  onChangeValue: (value) => jumpToPage(value),
                ),
                flex: 80,
              ),
              Expanded(
                child: IconButton(
                  icon: Icon(Icons.arrow_forward, color: appBarContentColor()),
                  onPressed: () => nextButtonPressed(),
                ),
                flex: 10,
              )
            ],
          );
        }): Container();
  }
}
